"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isNotEqualDate = isNotEqualDate;
exports.isTheSameDay = isTheSameDay;
exports.mapToFarsi = mapToFarsi;
exports.mapToLatin = mapToLatin;
exports.stripAnyThingButDigits = stripAnyThingButDigits;
exports.inspectDay = inspectDay;
exports.inspectMonth = inspectMonth;
exports.inspectYear = inspectYear;
exports.inspectHour = inspectHour;
exports.inspectMinute = inspectMinute;
exports.readDateFromValue = readDateFromValue;
exports.hasStringACharToGoToNext = hasStringACharToGoToNext;
exports.maxDayFor = maxDayFor;
exports.baseYear = baseYear;
exports.formatJalaali = formatJalaali;
exports.formatGregorian = formatGregorian;
exports.formatTime = formatTime;
exports.constructdate = constructdate;
exports.calcFirstDayOfMonth = calcFirstDayOfMonth;
exports.gregorianMonthLength = gregorianMonthLength;
exports.splitDateTimeValue = exports.splitDateValue = exports.isValueEmpty = exports.isValueValidDateTime = exports.isValueValidDate = exports.SEPERATORES_REGEX = exports.TIME_SEPERATOR = exports.MIDDLE_SEPERATOR = exports.DATE_SEPERATOR = exports.NUMBER_FORMAT_LATIN = exports.NUMBER_FORMAT_FARSI = void 0;

var _jalaaliJs = _interopRequireDefault(require("jalaali-js"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var NUMBER_FORMAT_FARSI = 'FARSI';
exports.NUMBER_FORMAT_FARSI = NUMBER_FORMAT_FARSI;
var NUMBER_FORMAT_LATIN = 'LATIN';
exports.NUMBER_FORMAT_LATIN = NUMBER_FORMAT_LATIN;
var DATE_SEPERATOR = '/'; // this is arabic date seperator ' ؍' but it is right to left glyph and as the numbers are left to right there will be caret position problem

exports.DATE_SEPERATOR = DATE_SEPERATOR;
var MIDDLE_SEPERATOR = '\xa0';
exports.MIDDLE_SEPERATOR = MIDDLE_SEPERATOR;
var TIME_SEPERATOR = ':';
exports.TIME_SEPERATOR = TIME_SEPERATOR;
var SEPERATORES_REGEX = new RegExp("[ ".concat(DATE_SEPERATOR, "]"), 'g');
exports.SEPERATORES_REGEX = SEPERATORES_REGEX;

function isNotEqualDate(m1, m2) {
  if (m1 && !m2 || !m1 && m2 || m1 && m2 && !isTheSameDay(m1, m2)) {
    return true;
  }

  return false;
}

function isTheSameDay(date1, date2) {
  if (date1.getFullYear() === date2.getFullYear() && date1.getMonth() === date2.getMonth() && date1.getDate() === date2.getDate()) {
    return true;
  }

  return false;
}

function mapToFarsi(str) {
  if (!str && str !== 0 && str !== '0') return str;
  return str.toString().replace(/[1234567890١٢٣٤٥٦٧٨٩٠]/gi, function (e) {
    var c = e.charCodeAt(0);
    return String.fromCharCode(c + (c < 60 ? 1728 : 144));
  });
}

function mapToLatin(str) {
  if (!str) return str;
  return str.toString().replace(/[۱۲۳۴۵۶۷۸۹۰١٢٣٤٥٦٧٨٩٠]/gi, function (e) {
    var c = e.charCodeAt(0);
    return String.fromCharCode(c - (c < 1770 ? 1584 : 1728));
  });
}

function stripAnyThingButDigits(str) {
  if (!str) return str;
  return str.toString().replace(/[^1234567890۱۲۳۴۵۶۷۸۹۰١٢٣٤٥٦٧٨٩٠]/gi, '');
}

function inspectDay(day, selectionStart, seperatorPosition, max) {
  var newDay = day.trim() === '' ? day : day.replace(/ /g, '0');
  var newStartPosition = selectionStart;
  var caretPosition = selectionStart - seperatorPosition - 1;
  console.log({
    day: day,
    selectionStart: selectionStart,
    seperatorPosition: seperatorPosition,
    caretPosition: caretPosition
  });

  if (newDay.length > 2) {
    // if(caretPosition<=2){
    //   newDay = newDay.substring(0, 2);
    //   newStartPosition = 8 + caretPosition;
    // }else if(caretPosition>2){
    //   newDay = newDay.substring(caretPosition-2, caretPosition);
    //   newStartPosition = 10;
    // }
    // debugger;
    newDay = newDay.substring(caretPosition - (newDay.length > 3 ? 2 : 1), caretPosition);

    if (newDay.length === 1) {
      newStartPosition = 9;
    } else {
      newStartPosition = 10;
    }
  }

  if (newDay.length === 2) {
    newStartPosition = 5;
  }

  if (newDay > max) {
    if (caretPosition === 0) {
      newDay = '  ';
      newStartPosition = 10;
    } else {
      newDay = day.substring(caretPosition - 1, caretPosition);
      newStartPosition = 9;
    }
  }

  return {
    newDay: newDay,
    newStartPosition: newStartPosition
  };
}

function inspectMonth(month, selectionStart, seperatorPosition) {
  var newMonth = month.trim() === '' ? month : month.replace(/ /g, '0');
  var newStartPosition = selectionStart;
  var caretPosition = selectionStart - seperatorPosition - 1;

  if (newMonth.length > 2) {
    // if(caretPosition<=2){
    //   newMonth = newMonth.substring(0, 2);
    //   newStartPosition = 5 + caretPosition;
    // }else if(caretPosition>2){
    //   newMonth = newMonth.substring(caretPosition-2, caretPosition);
    //   newStartPosition = 7;
    // }
    // debugger;
    newMonth = newMonth.substring(caretPosition - (newMonth.length > 3 ? 2 : 1), caretPosition);

    if (newMonth.length === 1) {
      newStartPosition = 6;
    } else {
      newStartPosition = 7;
    }
  }

  if (newMonth.length === 2) {
    newStartPosition = 2;
  }

  if (newMonth > 12) {
    if (caretPosition === 0) {
      newMonth = '  ';
      newStartPosition = 7;
    } else {
      newMonth = month.substring(caretPosition - 1, caretPosition);
      newStartPosition = 6;
    }
  }

  return {
    newMonth: newMonth,
    newStartPosition: newStartPosition
  };
}

function inspectYear(year, selectionStart) {
  var newYear = year;
  var newStartPosition = selectionStart;
  var caretPosition = selectionStart;

  if (newYear.length > 4) {
    if (caretPosition <= 4) {
      newYear = newYear.substring(0, 4);
      newStartPosition = caretPosition;
    } else if (caretPosition > 4) {
      newYear = newYear.substring(caretPosition - 4, caretPosition);
      newStartPosition = 4;
    }
  }

  return {
    newYear: newYear,
    newStartPosition: newStartPosition
  };
}

function inspectHour(hour, selectionStart, seperatorPosition) {
  var newHour = hour.trim() === '' ? hour : hour.replace(/ /g, '0');
  var newStartPosition = selectionStart;
  var caretPosition = selectionStart - seperatorPosition - 1;

  if (newHour.length > 2) {
    if (caretPosition <= 2) {
      newHour = newHour.substring(0, 2);
      newStartPosition = 11 + caretPosition;
    } else if (caretPosition > 2) {
      newHour = newHour.substring(caretPosition - 2, caretPosition);
      newStartPosition = 13;
    }
  }

  if (newHour > 23) {
    if (caretPosition === 0) {
      newHour = '  ';
      newStartPosition = 13;
    } else {
      newHour = hour.substring(caretPosition - 1, caretPosition);
      newStartPosition = 12;
    }
  }

  return {
    newHour: newHour,
    newStartPosition: newStartPosition
  };
}

;

function inspectMinute(minute, selectionStart, seperatorPosition) {
  var newMinute = minute.trim() === '' ? minute : minute.replace(/ /g, '0');
  var newStartPosition = selectionStart;
  var caretPosition = selectionStart - seperatorPosition - 1;

  if (newMinute.length > 2) {
    if (caretPosition <= 2) {
      newMinute = newMinute.substring(0, 2);
      newStartPosition = 14 + caretPosition;
    } else if (caretPosition > 2) {
      newMinute = newMinute.substring(caretPosition - 2, caretPosition);
      newStartPosition = 16;
    }
  }

  if (newMinute > 59) {
    if (caretPosition === 0) {
      newMinute = '  ';
      newStartPosition = 16;
    } else {
      newMinute = minute.substring(caretPosition - 1, caretPosition);
      newStartPosition = 15;
    }
  }

  return {
    newMinute: newMinute,
    newStartPosition: newStartPosition
  };
}

function readDateFromValue(value) {
  if (!value) return '';

  if (typeof value === 'string') {
    value = mapToLatin(value);
    var v = new Date(value);

    if (v.toString() === 'Invalid Date') {
      var d = isValueValidDateTime(value, true);

      if (d) {
        v = d;
      } else {
        d = isValueValidDate(value, true);

        if (d) {
          v = d;
        }
      }
    }

    if (v.getFullYear() < 1700) {
      var _d = isValueValidDateTime(value, false);

      if (_d) {
        v = _d;
      } else {
        _d = isValueValidDate(value, false);

        if (_d) {
          v = _d;
        }
      }
    }

    var j = _jalaaliJs.default.toJalaali(v);

    return {
      j: j,
      value: v
    };
  } else if (value instanceof Date) {
    if (value.toString() === 'Invalid Date') return '';

    var _j = _jalaaliJs.default.toJalaali(value);

    return {
      j: _j,
      value: value
    };
  } else {
    console.warn('unknown value type ', value);
  }

  return '';
}

function hasStringACharToGoToNext(str) {
  if (str.indexOf('.') >= 0) return true;
  if (str.indexOf(',') >= 0) return true; // if(str.indexOf('/')>=0) return true;

  if (str.indexOf('-') >= 0) return true;
  if (str.indexOf(';') >= 0) return true;
  if (str.indexOf('*') >= 0) return true;
  if (str.indexOf('#') >= 0) return true;
  if (str.indexOf(' ') >= 0) return true;
  if (str.indexOf('،') >= 0) return true;
  return false;
}

function maxDayFor(year, month, gregorian) {
  if (!month) return 31;
  if (!year) return 31;
  month = Number(month);
  year = Number(year);

  if (!gregorian) {
    return _jalaaliJs.default.jalaaliMonthLength(year, month);
  } else {
    return gregorianMonthLength(year, month);
  }
}

var jalaaliBaseYear = _jalaaliJs.default.toJalaali(new Date()).jy.toString();

var gregorianBaseYear = new Date().getFullYear().toString();

function baseYear(gregorian) {
  return gregorian ? gregorianBaseYear : jalaaliBaseYear;
}

function formatJalaali(j) {
  if (j instanceof Date) {
    j = _jalaaliJs.default.toJalaali(j);
  }

  return constructdate(j.jy, j.jm, j.jd, '/');
}

function formatGregorian(g) {
  return constructdate(g.getFullYear(), g.getMonth() + 1, g.getDate(), '/');
}

function formatTime(date) {
  var seperator = ':';

  var _minutes = date.getMinutes().toString();

  _minutes = '00'.substring(0, 2 - _minutes.length) + _minutes;

  var _hours = date.getHours().toString();

  _hours = '00'.substring(0, 2 - _hours.length) + _hours;
  return _hours + seperator + _minutes;
}

function constructdate(_year, _month, _day, seperator) {
  var _yeary, _monthm, _dayd;

  _dayd = _day.toString();
  _dayd = '00'.substring(0, 2 - _dayd.length) + _dayd;
  _monthm = _month.toString();
  _monthm = '00'.substring(0, 2 - _monthm.length) + _monthm;
  _yeary = _year.toString();
  _yeary = '0000'.substring(0, 4 - _yeary.length) + _yeary;
  return _yeary + seperator + _monthm + seperator + _dayd;
}

var isValueValidDate = function isValueValidDate(value, gregorian) {
  if (!value) return false;
  var splittedValue = splitDateValue(value);

  if (splittedValue === '' || !splittedValue) {
    return false;
  }

  var year = splittedValue.year,
      month = splittedValue.month,
      day = splittedValue.day;
  year = Number(year);
  month = Number(month);
  day = Number(day);
  if (isNaN(day) || isNaN(month) || isNaN(year)) return false;
  if (!gregorian && (year < 1300 || year > 1450)) return false;
  if (gregorian && (year < 1800 || year > 2150)) return false;
  if (month < 1 || month > 12) return false;
  if (day < 1 || day > 31) return false;
  if (day > maxDayFor(year, month, gregorian)) return false;

  if (gregorian) {
    var date = new Date(Date.UTC(year, month - 1, day, 0, 0));

    if (date.toString() === 'Invalid Date') {
      return false;
    }

    return date;
  } else {
    if (!_jalaaliJs.default.isValidJalaaliDate(year, month, day)) return false;

    var g = _jalaaliJs.default.toGregorian(year, month, day);

    var _date = new Date(Date.UTC(g.gy, g.gm - 1, g.gd, 0, 0));

    return _date;
  }
};

exports.isValueValidDate = isValueValidDate;

var isValueValidDateTime = function isValueValidDateTime(value, gregorian) {
  if (!value) return false;
  var splittedValue = splitDateTimeValue(value);

  if (splittedValue === '' || !splittedValue) {
    return false;
  }

  var year = splittedValue.year,
      month = splittedValue.month,
      day = splittedValue.day,
      hour = splittedValue.hour,
      minute = splittedValue.minute;
  if (hour.trim() === '' || minute.trim() === '') return false;
  year = Number(year);
  month = Number(month);
  day = Number(day);
  hour = Number(hour);
  minute = Number(minute);
  if (isNaN(day) || isNaN(month) || isNaN(year) || isNaN(hour) || isNaN(minute)) return false;
  if (!gregorian && (year < 1300 || year > 1450)) return false;
  if (gregorian && (year < 1800 || year > 2150)) return false;
  if (month < 1 || month > 12) return false;
  if (day < 1 || day > 31) return false;
  if (day > maxDayFor(year, month, gregorian)) return false;
  if (hour < 0 || hour >= 24) return false;
  if (minute < 0 || minute >= 60) return false;

  if (gregorian) {
    var date = new Date(year, month - 1, day, hour, minute);

    if (date.toString() === 'Invalid Date') {
      return false;
    }

    return date;
  } else {
    if (!_jalaaliJs.default.isValidJalaaliDate(year, month, day)) return false;

    var g = _jalaaliJs.default.toGregorian(year, month, day);

    var _date2 = new Date(g.gy, g.gm - 1, g.gd, hour, minute);

    return _date2;
  }
};

exports.isValueValidDateTime = isValueValidDateTime;

var isValueEmpty = function isValueEmpty(value) {
  if (value.replace(SEPERATORES_REGEX, '') === '') return true;
  return false;
};

exports.isValueEmpty = isValueEmpty;

var splitDateValue = function splitDateValue(value) {
  if (isValueEmpty(value)) {
    return '';
  }

  var seperator1 = value.indexOf(DATE_SEPERATOR);
  var seperator2 = value.indexOf(DATE_SEPERATOR, seperator1 + 1);

  if (seperator1 === -1 || seperator2 === -1) {
    return null;
  }

  var year = value.substring(0, seperator1);
  var month = value.substring(seperator1 + 1, seperator2);
  var day = value.substring(seperator2 + 1);
  return {
    year: year,
    month: month,
    day: day,
    seperator1: seperator1,
    seperator2: seperator2
  };
};

exports.splitDateValue = splitDateValue;

var splitDateTimeValue = function splitDateTimeValue(value) {
  if (isValueEmpty(value)) {
    return '';
  }

  var seperator1 = value.indexOf(DATE_SEPERATOR);
  var seperator2 = value.indexOf(DATE_SEPERATOR, seperator1 + 1);
  var seperator3 = value.indexOf(MIDDLE_SEPERATOR, seperator2 + 1);
  var seperator4 = value.indexOf(TIME_SEPERATOR, seperator3 + 1);

  if (seperator1 === -1 || seperator2 === -1 || seperator3 === -1 || seperator4 === -1) {
    return null;
  }

  var year = value.substring(0, seperator1);
  var month = value.substring(seperator1 + 1, seperator2);
  var day = value.substring(seperator2 + 1, seperator3);
  var hour = value.substring(seperator3 + 1, seperator4);
  var minute = value.substring(seperator4 + 1);
  return {
    year: year,
    month: month,
    day: day,
    hour: hour,
    minute: minute,
    seperator1: seperator1,
    seperator2: seperator2,
    seperator3: seperator3,
    seperator4: seperator4
  };
};

exports.splitDateTimeValue = splitDateTimeValue;

function calcFirstDayOfMonth(year, month, gregorian) {
  year = +year;
  month = +month;
  var fistDayDate;

  if (gregorian) {
    fistDayDate = new Date(year, month - 1, 1);
  } else {
    var firstDayJ = _jalaaliJs.default.toGregorian(year, month, 1);

    fistDayDate = new Date(firstDayJ.gy, firstDayJ.gm - 1, firstDayJ.gd);
  }

  return (fistDayDate.getDay() + 1) % 7;
}

function gregorianMonthLength(year, month) {
  return new Date(year, month, 0).getDate();
}